@echo off
    if [%1]==[] goto Usage
    if [%1]==[/?] goto Help
    if [%2]==[] goto InputCheck
REM
REM This file is called F_NAME.BAT per default. Call it whatever you like.
REM
REM You need enough free environment space for this batch file.
REM If there's not enough free space, f_name.bat will give you a warning.
REM
REM While f_name.bat tries to test your free environment space, you'll
REM probably need to check your config.sys for the following line:
REM
REM     SHELL=C:\DOS\COMMAND.COM C:\DOS\ /E:1024 /p
REM
REM The '/E:1024' sets your environment space - it will probably need to
REM be 1024 or higher (unless you're really economical with env-space).
REM
REM If you are not sure about free space, set fp and fn with long dummy
REM strings in autoexec.bat to get enough free space, eg.:
REM
REM set fp=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
REM set fn=xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
REM set fd=xx
REM set fe=xxxx
REM
REM Using dummy strings is necessary if you're going to execute
REM f_name.bat from a second command shell, eg. from Norton Commander.
REM In this case the total length reserved for f_name.bat should be up
REM to 130 bytes. My suggestion is, let the strings for fp and fn count
REM up to 124 bytes (eg. 62 each).
REM
REM Some releases of DOS (eg. some beta-releases/pre-releases of DOS 6.0
REM and some older DOS releases) does not support the batchcommand 'NOT'.
REM If you're still using such a release you cannot use this batchfile
REM since it uses this batchcommand.
REM
REM Please also note that f_name.bat cannot work properly if filespec is
REM longer than around 38 (? I don't know the exact length) characters. If
REM filespec is long, f_name.bat will fail at 'for %%f in ... do if ...'
REM lines.  The result of error is fairly unpredictable as DOS will try to
REM execute with a trucncated batch command line.  So, please use the
REM batch file for short filespecs (< 38??).
REM
REM For large batchfiles it is usually an advantage to use a
REM 'batch-compiler', which will convert the .bat file into a .com or
REM .exe file. With f_name.bat this could probably speed it up many
REM times, but it has not been possible to find a batch-compiler, which
REM will compile this batchfile. The compilers PWR14G.ZIP and
REM BAT2EX15.ZIP have been tested without success.
REM
REM This modified release is more solid when it comes to garbage input, it
REM is provided with help option, additional documentation and additional
REM checking for sufficient environment space and now remove the temporary
REM environment settings (P, S, T) at the bottom of the batchfile. The
REM structure is changed a bit, but the basic still is made by Wonkoo Kim.
REM
REM Please do not distribute this file without the above documentation
REM included in the batch-file. If you change the file please add your
REM name as a "modifier" as done below + document your changes. We do
REM not intend to hold a copyright, though. You may use, misuse or abuse
REM this batchfile as you see fit.
REM
REM This file is provided to you on a free basis. The author/modifiers
REM do not want to be hold responsible to whatever this batchfile is
REM doing. Use of this batchfile is entirely at your own risk.
REM
REM Wonkoo Kim (wkim+@pitt.edu), August 11, 1995
REM Modified by Claus Futtrup (odie@csek.iprod.auc.dk), August 23. 1995
REM
:Usage
    echo.
    echo Usage: %0 filespec
    echo.
    echo Returns: fd (drive), fp (path), fn (name), fe (extension)
    echo.
    echo Type %0 /? for additional help
    echo %0 is made by Wonkoo Kim, last modified by Claus Futtrup.
    echo.
    goto END
:Help
    cls
    echo %0 -- extracts the drive, path, name, and ext from file-path-name.
    echo.
    echo Return envs: FD (drive), FP (path), FN (name), FE (ext)
    echo Temp envs:   P, S, T
    echo.
    echo     INPUT FILE         fd        fp        fn        fe
    echo     ------------------ --------- --------- --------- ---------
    echo     c:                 c:
    echo     c:\                c:        \
    echo     abc                                    abc      
    echo     abc.tex                                abc       .tex
    echo     c:\abc.tex         c:        \         abc       .tex
    echo     c:tmp\abc.tex      c:        tmp\      abc       .tex
    echo     c:\tmp\abc.tex     c:        \tmp\     abc       .tex
    echo     c:tmp\tex\abc.tex  c:        tmp\tex\  abc       .tex
    echo     c:\tmp\tex\abc.tex c:        \tmp\tex\ abc       .tex
    echo.
    echo Please note this file isn't blazing fast + it needs a lot
    echo of environment space. See comments in %0 for more info.
    echo See top of file %0 for setup info and trouble shooting.
    echo.
    echo Wonkoo Kim (wkim+@pitt.edu), August 11, 1995
    echo Modified by Claus Futtrup (odie@csek.iprod.auc.dk), August 23. 1995
    echo.
    goto END
:InputCheck
    for %%f in (%1) do if "%%f"=="%1" goto Okay
    echo *** ERROR: Please do not use wildcards in input file name.
    goto END
:Okay
    set p=
    set fp=
    set fe=
    set fn=%1
    set s=XXXXXXX%fn%
    set t=%fn%
    set s=
    if [%t%]==[%1] goto GetDrive
:EnvErr
    echo 
    echo *** ERROR: Not enough environment space!
    echo *** See documentation at top of file '%0'
    goto END
:GetDrive
    for %%f in (/%t%) do set fn=%%f
    for %%f in (/%t%) do if not [%%f]==[%fn%] set fd=%%f
    if [%fn%]==[:] goto DriveOnly
    set t=%fn%
    for %%f in (/%t%) do set fn=%%f
    if [:%fn%]==[%t%] goto DriveFound
    set fd=
    set fn=%1
    goto GetPath
:DriveOnly
    set fn=
:DriveFound
    set fd=%fd%:
:GetPath
    set s=%fn%
:PathLoop
    set t=%s%
    for %%f in (/%t%) do set s=%%f
    for %%f in (/%t%) do if not [%%f]==[%s%] set p=%p%%%f
    if "\%s%"=="%t%" goto Separator
    if [%s%]==[%t%] goto PathCheck
    goto PathLoop
:Separator
    set fn=%s%
    set fp=%p%
    goto PathLoop
:PathCheck
    if not [%fn%]==[\] goto GetExt
    set fp=%fn%
    set fn=
    goto Done
:GetExt
    set s=%fn%
    set fe=%fn%
    set fn=
:ExtLoop
    set t=%fe%
    for %%f in (/%t%) do set fe=%%f
    if ".%fe%"=="%t%" goto ExtFound
    if [%fe%]==[%t%] goto NoExt
    for %%f in (/%t%) do if not [%%f]==[%fe%] set fn=%fn%%%f
    goto ExtLoop
:ExtFound
    set fe=.%fe%
    goto Done
:NoExt
    if not [%fe%]==[.]  set fn=%s%
    set fe=
:Done
    echo DRIVE=%fd%  PATH=%fp%  NAME=%fn%  EXT=%fe%
:END
    set p=
    set s=
    set t=
